Automatically add git remotes for Gitlab, Bitbucket, Sourcehut, and
Codeberg, if the remote repositories exist.
add_git_remotes(force_bb = FALSE)
Arguments
- force_bb
Bitbucket repos can not be directly queried; this option
simply forces a Bitbucket remote to be added regardless of whether or not
that remote repository actually exists or not.