Note that no path arguments are used or recognised, and this function can only be called and used in the current working directory.
debug()Nothing; this just modifies or writes a 'Makevars' script. The debugger can then be started with a single extra command.