R/github-notifications.R
mark_gh_notifications_as_read.RdThis does not remove them from the top of the most recent notifications list, but just marks them as read. There is currently no way to remove them from the list.
mark_gh_notifications_as_read()