This accepts only the single parameter which corresponds to a number from the most recently extracted and cached notification list.

open_gh_notification(what = "github", n)

Arguments

what

Service to get notifications from; one of "github" or "codeberg" (case-insensitive).

n

Number of notification as generated from gh_notifications

Value

Nothing