Function to check status on R-Universe and issue any warnings.

r_univ_build_status(univ = "ropensci-review-tools", maintainer = NULL)

Arguments

univ

Name of universe, as sub-domain prefix of main R-universe URL.

maintainer

Optional name of maintainer. If given, results with be filtered to only those packages within specified univsere maintained by that person.

Value

Nothing. Function is called only for its side-effect of generating messages in an active terminal session.