Scans all directories above where function is called, extracts maximum version number of all unique GitHub actions used in every workflow, and reports paths to any repositories which use workflow versions less than those.

workflow_updates(root = ".", max_depth = 2L)

Arguments

root

Directory in which function is to be run.

max_depth

Maximal recursive depth for trawling sub-directories.

Value

(Invisibly) A tibble data.frame of all obsolete workflow versions. Function is primarily intended to be called for the side-effect of printing all results to screen.