R/github-notifications.R
open_gh_notification.RdThis accepts only the single parameter which corresponds to a number from the most recently extracted and cached notification list.
open_gh_notification(what = "github", n)Service to get notifications from; one of "github" or "codeberg" (case-insensitive).
Number of notification as generated from gh_notifications
Nothing